# -*- coding: utf-8 -*-

# FOGLAMP_BEGIN
# See: http://foglamp.dianomic.com
# FOGLAMP_END


__author__ = "Mohit Rajput"
__copyright__ = "Copyright (c) 2024 Dianomic Systems"
__license__ = "Apache 2.0"
__version__ = "${VERSION}"


import random


def weighted_random_categorical_value(
    options = ["low", "mid", "high"],
    last_value = "low",
    last_value_chance_multiplier = 10
):
    """Select a weighted random categorical value from the allowed categories.

    Args:
        options: allowed categories
        last_value: last selected category
        last_value_chance_multiplier: weight multiplier for the last category

    Return:
        randomly weighted selected category
    """
    chances = [1] * len(options)
    chances[options.index(last_value)] *= last_value_chance_multiplier
    return random.choices(options, weights=chances)[0]


def weighted_random_continuous_value(
    min_value=1.0, max_value=10.0, last_value = 5.0, delta_weight=2,
    return_discrete_value=False
):
    """Select a random numeric value with weight around the last value.

    Args:
        min_value: minimum allowed value
        max_value: maximum allowed value
        last_value: last selected value
        delta_weight: margin around the last value allowed to change
        return_discrete_value: select output values as int or float

    Return:
        randomly weighted selected value
    """
    standard_current_value = (
        (last_value + random.random() * random.randint(-1, 1) * delta_weight) /
        (max_value - min_value)
    )
    if (standard_current_value > 1):
        standard_current_value = 2 - standard_current_value
    elif (standard_current_value < 0):
        standard_current_value = standard_current_value * -1
    output = standard_current_value * (max_value - min_value) + min_value

    if return_discrete_value:
        output = int(round(output, 0))
    return output
